@@ -20,7 +20,6 @@ from .accountscout import AccountScout as AccountScout
 from .accountscout import ScoutReport as ScoutReport
 from .addressableaccount import AddressableAccount as AddressableAccount
 from .arguments import parse_args as parse_args
-from .arguments import output as output
 from .balancesheet import BalanceSheet as BalanceSheet
 from .cache import Cache as Cache
 from .cache import MarketCache as MarketCache
@@ -37,8 +36,10 @@ from .client import NodeIsBehindException as NodeIsBehindException
 from .client import RateLimitException as RateLimitException
 from .client import RPCCaller as RPCCaller
 from .client import SlotHolder as SlotHolder
+from .client import StaleSlotException as StaleSlotException
 from .client import TooManyRequestsRateLimitException as TooManyRequestsRateLimitException
 from .client import TooMuchBandwidthRateLimitException as TooMuchBandwidthRateLimitException
+from .client import TransactionAlreadyProcessedException as TransactionAlreadyProcessedException
 from .client import TransactionException as TransactionException
 from .combinableinstructions import CombinableInstructions as CombinableInstructions
 from .constants import MangoConstants as MangoConstants
@@ -122,6 +123,8 @@ from .marketoperations import MarketOperations as MarketOperations
 from .marketoperations import NullMarketInstructionBuilder as NullMarketInstructionBuilder
 from .marketoperations import NullMarketOperations as NullMarketOperations
 from .metadata import Metadata as Metadata
+from .modelstate import EventQueue as EventQueue
+from .modelstate import NullEventQueue as NullEventQueue
 from .modelstate import ModelState as ModelState
 from .notification import CompoundNotificationTarget as CompoundNotificationTarget
 from .notification import ConsoleNotificationTarget as ConsoleNotificationTarget
@@ -161,6 +164,7 @@ from .orders import OrderBook as OrderBook
 from .orders import Side as Side
 from .ownedinstrumentvalue import OwnedInstrumentValue as OwnedInstrumentValue
 from .oraclefactory import create_oracle_provider as create_oracle_provider
+from .output import output as output
 from .parse_account_info_to_orders import parse_account_info_to_orders as parse_account_info_to_orders
 from .perpaccount import PerpAccount as PerpAccount
 from .perpeventqueue import PerpEvent as PerpEvent
@@ -239,6 +243,9 @@ from .watchers import build_perp_open_orders_watcher as build_perp_open_orders_w
 from .watchers import build_price_watcher as build_price_watcher
 from .watchers import build_serum_inventory_watcher as build_serum_inventory_watcher
 from .watchers import build_orderbook_watcher as build_orderbook_watcher
+from .watchers import build_serum_event_queue_watcher as build_serum_event_queue_watcher
+from .watchers import build_spot_event_queue_watcher as build_spot_event_queue_watcher
+from .watchers import build_perp_event_queue_watcher as build_perp_event_queue_watcher
 from .websocketsubscription import IndividualWebSocketSubscriptionManager as IndividualWebSocketSubscriptionManager
 from .websocketsubscription import SharedWebSocketSubscriptionManager as SharedWebSocketSubscriptionManager
 from .websocketsubscription import WebSocketAccountSubscription as WebSocketAccountSubscription
